local AddonName, AddonTable = ...
local L = AddonTable.L
--[===[@debug@
local DEBUG = true
--@end-debug@]===]
local function DebugPrint(errorMessage)
   if DEBUG then
      print(RED_FONT_COLOR_CODE..AddonName..":"..errorMessage)
   end
end

--Lookup table to convert internal item tables to a visible section name
local tableToContainer = {
	["ArtifactItems"] = L["Artifact Power"],
	["AncientManaItems"] = L["Ancient Mana"],
	["ChampionUpgradeTokens"] = L["Champion Upgrades"],
	["ChampionEquipment"] = L["Champion Equipment"],
   ["Bait"] = L["Bait"]
}

--AdiBags filters 
local AdiBags = LibStub("AceAddon-3.0"):GetAddon("AdiBags")
local legionFilter = AdiBags:RegisterFilter(L["Legion"], 91)
legionFilter.uiName = L["Legion"]
legionFilter.uiDesc = L["Put items from Legion in their own sections."]

function legionFilter:Filter(slotData)
   for tableName,itemTable in pairs(AddonTable.ItemTables) do
      if legionFilter.db.profile[tableName] then
         if itemTable[slotData.itemId] then
            return tableToContainer[tableName]
         end
      end
   end
   --Artifact Relics
   if self.db.profile.ArtifactRelics then
      local itemSubType,_,_,_,_,itemClassID, itemSubClassID = select(7,GetItemInfo(slotData.itemId))
      if itemClassID==3 and itemSubClassID==11 then --Class Gem Subtype Artifact Relic
         return itemSubType
      end
   end
end

function legionFilter:OnInitialize()
   self.db = AdiBags.db:RegisterNamespace(L["Legion"], { profile = { 
      ArtifactItems = true,
      AncientManaItems = true,
      ArtifactRelics = true,
      ChampionUpgradeTokens = true,
      ChampionEquipment = true,
      MergeChampionItems = true,
      Bait = true} })
    if self.db.profile.MergeChampionItems then
      tableToContainer["ChampionEquipment"] = L["Champion Upgrades"] --Remap to champion upgrade section
   end
end

function legionFilter:GetOptions()
   return {
      ArtifactItems = {
         name = L["Artifact Power"],
         desc = L['Create a section for Artifact Power items.'],
         type = 'toggle',
         order = 10,
      },
      AncientManaItems = {
         name = L["Ancient Mana"],
         desc = L['Create a section for Ancient Mana items.'],
         type = 'toggle',
         order = 20,
      },
      ArtifactRelics = {
         name = L['Artifact Relics'],
         desc = L['Create a section for Artifact Relics.'],
         type = 'toggle',
         order = 30,
      },
      MergeChampionItems = {
         name = L["Merge Champion Items"],
         desc = L['Put Champion Equipment and Upgrades in one section.'],
         type = 'toggle',
         order = 40,
         set = function(info,val) 
            if val then
               self.db.profile.ChampionUpgradeTokens = true
               self.db.profile.ChampionEquipment = true
               tableToContainer["ChampionEquipment"] = L["Champion Upgrades"] --Remap to champion upgrade section
            else
               tableToContainer["ChampionEquipment"] = L["Champion Equipment"] --Restore default mapping
            end
            self:SendMessage('AdiBags_FiltersChanged', true)
            self.db.profile.MergeChampionItems = val 
         end,
      },
      ChampionUpgradeTokens = {
         name = L["Champion Upgrades"],
         desc = L['Create a section for Champion Upgrades items.'],
         type = 'toggle',
         order = 41,
         disabled = function() return self.db.profile.MergeChampionItems end,
      },
      ChampionEquipment = {
         name = L["Champion Equipment"],
         desc = L['Create a section for Champion Equipment.'],
         type = 'toggle',
         order = 42,
         disabled = function() return self.db.profile.MergeChampionItems end,
      },
      Bait = {
         name = L['Bait'],
         desc = L['Create a section for Bait.'],
         type = 'toggle',
         order = 30,
      },
   }, AdiBags:GetOptionHandler(self, true)
end